@@ -1,6 +1,5 @@
-
 from .dynamical_systems import *
 from .model import *
-from .regularizers import *
+from .functions import *
 
-__version__ = '0.0.1'
\ No newline at end of file
+__version__ = "0.0.1"
